@@ -1011,6 +1011,11 @@ dynamicforms = {
       if ($field.data('select2').options.options.ajax) {
         var opt = $('<option value="' + value + '"></option>').text(select2_ajax_option_text);
         $field.append(opt);
+      } else {
+        if ($field.data("allow-tags") && !$field.find("option[value='" + value + "']").length) {
+          var newOption = new Option(value, value, true, true);
+          $field.append(newOption).trigger('change');
+        }
       }
       $field.val(value);
       dynamicforms.setSelect2Order($field, value);
@@ -1632,7 +1637,37 @@ dynamicforms = {
             .create(document.querySelector("[id='" + fieldId + "']"), {
               toolbar: {
                 removeItems: ['imageUpload', 'mediaEmbed'],
-              },
+			          items: ["heading", "|", "bold", "italic", "link", "fontColor", "bulletedList", "numberedList", "|", "indent",
+				          "outdent", "|", "imageUpload", "blockQuote", "insertTable", "mediaEmbed", "undo", "redo"],
+		          },
+              fontColor: {
+			          colors: [
+                  {
+                    label: 'Alert - Primary',
+                    color: 'primary',
+                  },
+                  {
+                    color: 'secondary',
+                    label: 'Alert - Secondary'
+                  },
+                  {
+                    color: 'success',
+                    label: 'Alert - Success'
+                  },
+                  {
+                    color: 'danger',
+                    label: 'Alert - Danger'
+                  },
+                  {
+                    color: 'warning',
+                    label: 'Alert - Warning',
+                  },
+                  {
+                    color: 'info',
+                    label: 'Alert - Info',
+                  },
+                ]
+		          },
               heading: {
                 options: [
                   {model: 'paragraph', title: 'Paragraph', class: 'ck-heading_paragraph'},
